==> iRRAM_2004_01.tar.gz: iRRAM_2004_01/include/GMP_intrat.h <==
/*

GMP_intrat.h -- extension to the GMP integer/rationals for the iRRAM library
 
Copyright (C) 2001-2003 Norbert Mueller
 
This file is part of the iRRAM Library.
 
The iRRAM Library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at your
option) any later version.
 
The iRRAM Library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
License for more details.
 
You should have received a copy of the GNU Library General Public License
along with the iRRAM Library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA. 
*/

/*
Changelog: (initial version by Tom van Diessen)  

  2001-09-10 removal of several unneeded functions by Norbert
*/

#include <stdlib.h>
#include <stdio.h>
#include "gmp.h"
#ifdef __cplusplus
extern "C" {
#endif

#define GMP_min -1000000000
#define GMP_max 1000000000

/********** MP integer type definition **********/

typedef mpz_ptr int_gmp_type;
typedef struct {unsigned long body;} int_gmp_sizetype;

/********** counting vars **********/

extern long int_gmp_var_count;
long int_gmp_getsize(int_gmp_type z);


/********** initialization function **********/

int_gmp_type int_gmp_init();

void int_gmp_free(int_gmp_type z);

/********** Conversion functions **********/

void int_gmp_int2int(const long int i, int_gmp_type z);
void int_gmp_double2int(const double d, int_gmp_type z);
void int_gmp_string2int(const char* s, int_gmp_type z, int b);
long int_gmp_int2long(const int_gmp_type z);

/********** standard arithmetic functions for MP integer **********/

void int_gmp_add(int_gmp_type z1, int_gmp_type z2, int_gmp_type z);
void int_gmp_sub(int_gmp_type z1, int_gmp_type z2, int_gmp_type z);
void int_gmp_mul(int_gmp_type z1, int_gmp_type z2, int_gmp_type z);
void int_gmp_div(int_gmp_type z1, int_gmp_type z2, int_gmp_type z);
void int_gmp_add_ui(int_gmp_type z1, unsigned long z2, int_gmp_type z);
void int_gmp_sub_ui(int_gmp_type z1, unsigned long z2, int_gmp_type z);
void int_gmp_mul_si(int_gmp_type z1,   signed long z2, int_gmp_type z);
void int_gmp_div_ui(int_gmp_type z1, unsigned long z2, int_gmp_type z);
void int_gmp_abs(int_gmp_type z1, int_gmp_type z);
void int_gmp_neg(int_gmp_type z1, int_gmp_type z);


/********** more MP integer functions *********/

void int_gmp_root(int_gmp_type z1, unsigned long int z2, int_gmp_type z);
void int_gmp_power_i(int_gmp_type z1, unsigned long int z2, int_gmp_type z);
void int_gmp_power_ii(unsigned long int z1, unsigned long int z2, int_gmp_type z);
void int_gmp_fac(unsigned long int z1, int_gmp_type z);
void int_gmp_modulo(int_gmp_type z1, int_gmp_type z2, int_gmp_type z3);
void int_gmp_sqrt(int_gmp_type z1, int_gmp_type z);
void int_gmp_shift(int_gmp_type z1, int_gmp_type z, long p);
long int_gmp_log(int_gmp_type z);


/********** comparison functions **********/

int int_gmp_cmp(int_gmp_type z1, int_gmp_type z2);
int int_gmp_sgn(int_gmp_type z);


/********** output functions for MP integers **********/

void int_gmp_writee(int_gmp_type z, long w);
char* int_gmp_swritee(int_gmp_type z, long w);
void int_gmp_write(int_gmp_type z, long w);
void int_gmp_outstr(int_gmp_type z, long w);
void int_gmp_printf(int_gmp_type z);
char* int_gmp_sprintf(int_gmp_type z);


/********** copying MP integers with/without initializing **********/

void int_gmp_duplicate_w_init(int_gmp_type z1, int_gmp_type *z2);
void int_gmp_duplicate_wo_init(int_gmp_type z1, int_gmp_type z2);



/********** MP rational type definition **********/

typedef mpq_ptr rat_gmp_type;

/********** counting vars **********/

extern long rat_gmp_var_count;
int rat_gmp_getsize(rat_gmp_type z);
long rat_gmp_binsize(rat_gmp_type z);


/********** initialization function **********/

rat_gmp_type rat_gmp_init();

void rat_gmp_free(rat_gmp_type z);
long rat_gmp_size(rat_gmp_type z);
long rat_gmp_log(rat_gmp_type z);

void rat_gmp_canon(rat_gmp_type z);

// ********** standard arithmetic functions for MP rational **********
// ********** +-*/ *********

void rat_gmp_add(const rat_gmp_type z1, const rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_sub(rat_gmp_type z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_mul(rat_gmp_type z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_div(rat_gmp_type z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_add_ui(rat_gmp_type z1, unsigned long z2, rat_gmp_type z);
void rat_gmp_sub_ui(rat_gmp_type z1, unsigned long z2, rat_gmp_type z);
void rat_gmp_mul_si(rat_gmp_type z1, unsigned long z2, rat_gmp_type z);
void rat_gmp_div_si(rat_gmp_type z1, unsigned long z2, rat_gmp_type z);
void rat_gmp_si_div(unsigned long z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_abs(rat_gmp_type z1, rat_gmp_type z);


// ********** more MP rational functions *********/
// ********** ^!%>>... **********/

void rat_gmp_power(rat_gmp_type z1, unsigned long int z2, rat_gmp_type z);
void rat_gmp_powerr(rat_gmp_type z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_shift(rat_gmp_type z1, rat_gmp_type z, long p);


// ********** output functions for MP rationals **********

void rat_gmp_writee(const rat_gmp_type z, const long w);
char* rat_gmp_swritee(const rat_gmp_type z, const long w);
void rat_gmp_write(const rat_gmp_type z, const long w);
void rat_gmp_outstr(const rat_gmp_type z, const long w);
void rat_gmp_printf(const rat_gmp_type z);
char* rat_gmp_sprintf(const rat_gmp_type z);
void rat_gmp_string_2_rat(rat_gmp_type z, const char* s);
void rat_gmp_double_2_rat(rat_gmp_type z, const double d);

void rat_gmp_get_numerator(int_gmp_type z, const rat_gmp_type z1);
void rat_gmp_get_denominator(int_gmp_type z, const rat_gmp_type z1);


// ********** copying MP rationals with/without initializing **********

void rat_gmp_duplicate_w_init(const rat_gmp_type z1, rat_gmp_type *z2);
void rat_gmp_duplicate_wo_init(const rat_gmp_type z1, rat_gmp_type z2);
#ifdef __cplusplus
}
#endif

==> iRRAM_2004_02.tar.gz: iRRAM_2004_02/include/GMP_intrat.h <==
/*

GMP_intrat.h -- extension to the GMP integer/rationals for the iRRAM library
 
Copyright (C) 2001-2003 Norbert Mueller
 
This file is part of the iRRAM Library.
 
The iRRAM Library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at your
option) any later version.
 
The iRRAM Library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
License for more details.
 
You should have received a copy of the GNU Library General Public License
along with the iRRAM Library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA. 
*/

/*
Changelog: (initial version by Tom van Diessen)  

  2001-09-10 removal of several unneeded functions by Norbert
*/

#ifndef GMP_int_rat
#define GMP_int_rat

#include <stdlib.h>
#include <stdio.h>
#include "gmp.h"
#ifdef __cplusplus
extern "C" {
#endif

#define GMP_min -1000000000
#define GMP_max 1000000000

/********** MP integer type definition **********/

typedef mpz_ptr int_gmp_type;
typedef struct {unsigned int body;} int_gmp_sizetype;

/********** counting vars **********/

extern int int_gmp_var_count;
int int_gmp_size(int_gmp_type z);


/********** initialization function **********/

int_gmp_type int_gmp_init();

void int_gmp_free(int_gmp_type z);

/********** Conversion functions **********/

void int_gmp_int2integer(const int i, int_gmp_type z);
void int_gmp_double2int(const double d, int_gmp_type z);
void int_gmp_string2int(const char* s, int_gmp_type z, int b);
int int_gmp_integer2int(const int_gmp_type z);

/********** standard arithmetic functions for MP integer **********/

void int_gmp_add(int_gmp_type z1, int_gmp_type z2, int_gmp_type z);
void int_gmp_sub(int_gmp_type z1, int_gmp_type z2, int_gmp_type z);
void int_gmp_mul(int_gmp_type z1, int_gmp_type z2, int_gmp_type z);
void int_gmp_div(int_gmp_type z1, int_gmp_type z2, int_gmp_type z);
void int_gmp_add_ui(int_gmp_type z1, unsigned int z2, int_gmp_type z);
void int_gmp_sub_ui(int_gmp_type z1, unsigned int z2, int_gmp_type z);
void int_gmp_mul_si(int_gmp_type z1,   signed int z2, int_gmp_type z);
void int_gmp_div_ui(int_gmp_type z1, unsigned int z2, int_gmp_type z);
void int_gmp_abs(int_gmp_type z1, int_gmp_type z);
void int_gmp_neg(int_gmp_type z1, int_gmp_type z);


/********** more MP integer functions *********/

void int_gmp_root(int_gmp_type z1, unsigned int z2, int_gmp_type z);
void int_gmp_power_i(int_gmp_type z1, unsigned int z2, int_gmp_type z);
void int_gmp_power_ii(unsigned int z1, unsigned int z2, int_gmp_type z);
void int_gmp_fac(unsigned int z1, int_gmp_type z);
void int_gmp_modulo(int_gmp_type z1, int_gmp_type z2, int_gmp_type z3);
void int_gmp_sqrt(int_gmp_type z1, int_gmp_type z);
void int_gmp_shift(int_gmp_type z1, int_gmp_type z, int p);
int int_gmp_log(int_gmp_type z);


/********** output functions for MP integers **********/

void int_gmp_writee(int_gmp_type z, int w);
char* int_gmp_swritee(int_gmp_type z, int w);
void int_gmp_write(int_gmp_type z, int w);
void int_gmp_outstr(int_gmp_type z, int w);
void int_gmp_printf(int_gmp_type z);
char* int_gmp_sprintf(int_gmp_type z);


/********** copying MP integers with/without initializing **********/

void int_gmp_duplicate_w_init(int_gmp_type z1, int_gmp_type *z2);
void int_gmp_duplicate_wo_init(int_gmp_type z1, int_gmp_type z2);


/********** MP rational type definition **********/

typedef mpq_ptr rat_gmp_type;

/********** counting vars **********/

extern int rat_gmp_var_count;

/********** initialization function **********/

rat_gmp_type rat_gmp_init();

void rat_gmp_free(rat_gmp_type z);

void rat_gmp_canon(rat_gmp_type z);

// ********** standard arithmetic functions for MP rational **********
// ********** +-*/ *********

void rat_gmp_add(const rat_gmp_type z1, const rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_sub(rat_gmp_type z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_mul(rat_gmp_type z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_div(rat_gmp_type z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_add_ui(rat_gmp_type z1, unsigned int z2, rat_gmp_type z);
void rat_gmp_sub_ui(rat_gmp_type z1, unsigned int z2, rat_gmp_type z);
void rat_gmp_mul_si(rat_gmp_type z1, unsigned int z2, rat_gmp_type z);
void rat_gmp_div_si(rat_gmp_type z1, unsigned int z2, rat_gmp_type z);
void rat_gmp_si_div(unsigned int z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_abs(rat_gmp_type z1, rat_gmp_type z);


// ********** more MP rational functions *********/
// ********** ^!%>>... **********/

void rat_gmp_power(rat_gmp_type z1, unsigned int z2, rat_gmp_type z);
void rat_gmp_powerr(rat_gmp_type z1, rat_gmp_type z2, rat_gmp_type z);
void rat_gmp_shift(rat_gmp_type z1, rat_gmp_type z, int p);


// ********** output functions for MP rationals **********

char* rat_gmp_swritee(const rat_gmp_type z, const int w);
char* rat_gmp_sprintf(const rat_gmp_type z);


void rat_gmp_string_2_rat(rat_gmp_type z, const char* s);
void rat_gmp_double_2_rat(rat_gmp_type z, const double d);

void rat_gmp_get_numerator(int_gmp_type z, const rat_gmp_type z1);
void rat_gmp_get_denominator(int_gmp_type z, const rat_gmp_type z1);


// ********** copying MP rationals with/without initializing **********

void rat_gmp_duplicate_w_init(const rat_gmp_type z1, rat_gmp_type *z2);
void rat_gmp_duplicate_wo_init(const rat_gmp_type z1, rat_gmp_type z2);

// ********* sign and comparison of integer and rational 

int int_gmp_sgn(const int_gmp_type z);
int rat_gmp_sgn(const rat_gmp_type z);

int int_gmp_cmp(const int_gmp_type z1,const  int_gmp_type z2);
int rat_gmp_cmp(const rat_gmp_type z1,const  rat_gmp_type z2);

#ifdef __cplusplus
}
#endif

#endif //ifndef GMP_int_rat
